@@ -40,11 +40,13 @@ I18N_NOOP("KDE Minigolf Game");
 
 int main(int argc, char **argv)
 {
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("kolf");
 
-	KAboutData aboutData( QStringLiteral("kolf"), i18n("Kolf"), KOLF_VERSION_STRING, i18n(description), KAboutLicense::GPL, i18n("(c) 2002-2010, Kolf developers"),  QStringLiteral("https://games.kde.org/kolf"));
+	KAboutData aboutData( QStringLiteral("kolf"), i18n("Kolf"), QStringLiteral(KOLF_VERSION_STRING), i18n(description), KAboutLicense::GPL, i18n("(c) 2002-2010, Kolf developers"),  QStringLiteral("https://games.kde.org/kolf"));
 
 	aboutData.addAuthor(i18n("Stefan Majewsky"), i18n("Current maintainer"), QStringLiteral("majewsky@gmx.net"));
 	aboutData.addAuthor(i18n("Jason Katz-Brown"), i18n("Former main author"), QStringLiteral("jasonkb@mit.edu"));
